# WPScraper pckage

This package collect and store the most recent articles from a WordPress website.

It currently supports CSV and Sqlite data stores.

# Files
wpscraper.py
datastores.py
test_wpscraper.py

# Installation
pip install wpscraper